<?php

/**
 * @file
 * Contains \Drupal\youtube_block\Form\YoutubeBlockForm.
 */

namespace Drupal\youtube_block\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Link;
use Drupal\Core\Url;


/**
 * Configure youtube_block settings for this site.
 */
class YoutubeBlockForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormID() {
    return 'youtube_block_config_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['youtube_block.settings'];
  }

  // dbtNOTE <<maybe comment out the following to so that the aspect about going to a website to retrieve the uid and key is note required... just let the dev_user dig this out manually.>>

//  /**
//   * {@inheritdoc}
//   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    // Get module configuration.
    $config = $this->config('youtube_block.settings');

//    $options = [
//      'query' => [
//        'client_id' => '759ec610e0c1416baa8a8a6b41552087',
//        'redirect_uri' => 'http://youtube.yanniboi.com/configure/youtube',
//        'response_type' => 'code',
//      ],
//    ];

    $url = Url::fromUri('https://youtube.com/account_advanced/');
    $link = Link::fromTextAndUrl('here', $url)->toRenderable();
    $link['#attributes']['target'] = '_blank';


//    $form['authorise'] = array(
//      '#markup' => t('To configure your youtube account you need to authorise your account.  To do this, click %link.', array('%link' => render($link))),
//    );

    $form['authorise'] = array(
      '#markup' => t('Each YouTube channel has a unique user ID and channel ID. These are used to refer to the channel in certain apps and services.  To find the user ID and channel ID for your channel, sign into Youtube and check your advanced account settings page.   To do this, click %link.', array('%link' => render($link))),
    );

    $form['user_id'] = array(
      '#type' => 'textfield',
      '#title' => t('User Id'),
      '#description' => t('Your unique Youtube user ID. Eg. WJLOW9fg9qeUHP47luEOxg'),
      '#default_value' => $config->get('user_id'),
    );

    $form['channel_id'] = array(
      '#type' => 'textfield',
      '#title' => t('Channel ID'),
      '#description' => t('Your Youtube channel ID. Eg. UCWJLOW9fg9qeUHP47luEOxg'),
      '#default_value' => $config->get('channel_id'),
    );

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $user_id = $form_state->getValue('user_id');
    $access_token = $form_state->getValue('channel_id');

    // Get module configuration.
    $this->config('youtube_block.settings')
      ->set('user_id', $user_id)
      ->set('access_token', $channel_id)
      ->save();

    parent::submitForm($form, $form_state);
  }

}
